import { defineStore } from 'pinia'
import { ref, type Ref } from 'vue'

export interface Authenticated {
  username: string
  password: string
}

export type AuthenticationState = Authenticated | null

export const useAuthStore = defineStore('auth', () => {
  const state: Ref<AuthenticationState> = ref(null)
  function logIn(username: string, password: string) {
    state.value = { username: username, password: password }
  }
  function logOut() {
    state.value = null
  }
  function getBasicAuth() {
    if (!state.value) return null
    return btoa(state.value.username + ':' + state.value.password)
  }
  return { state, logIn, logOut, getBasicAuth }
})
